@@ -3,6 +3,14 @@ use std::fmt;
 use super::*;
 
 impl Cluster {
+    pub fn infrastructure(&self) -> Option<&corev1::ObjectReference> {
+        self.spec.infrastructure_ref.as_ref()
+    }
+
+    pub fn control_plane(&self) -> Option<&corev1::ObjectReference> {
+        self.spec.control_plane_ref.as_ref()
+    }
+
     pub fn infrastructure_ready(&self) -> bool {
         self.status
             .as_ref()
@@ -17,6 +25,14 @@ impl Cluster {
             .unwrap_or_default()
     }
 
+    pub fn cluster_network(&self) -> Option<&ClusterNetwork> {
+        self.spec.cluster_network.as_ref()
+    }
+
+    pub fn topology(&self) -> Option<&Topology> {
+        self.spec.topology.as_ref()
+    }
+
     pub fn phase(&self) -> ClusterPhase {
         self.status
             .as_ref()
@@ -35,10 +51,6 @@ impl Cluster {
             .and_then(|status| status.conditions.as_mut())
     }
 
-    pub fn cluster_network(&self) -> Option<&ClusterNetwork> {
-        self.spec.cluster_network.as_ref()
-    }
-
     pub fn pod_cidrs(&self) -> Option<&[String]> {
         self.cluster_network()
             .and_then(|cn| cn.pods.as_ref())
