@@ -1,7 +1,7 @@
 use super::*;
 
 /// KubeadmControlPlaneSpec defines the desired state of KubeadmControlPlane.
-#[derive(Clone, Debug, Serialize, Deserialize, CustomResource)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize, CustomResource)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 #[kube(
