@@ -16,7 +16,7 @@ mod tags;
 mod types;
 
 /// AWSClusterSpec defines the desired state of an EC2-based Kubernetes cluster.
-#[derive(CustomResource, Serialize, Deserialize, Clone, Debug)]
+#[derive(CustomResource, Serialize, Deserialize, Clone, Debug, Default)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 #[kube(
@@ -90,7 +90,7 @@ pub struct AWSClusterSpec {
 }
 
 /// AWSClusterStatus defines the observed state of AWSCluster.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct AWSClusterStatus {
